diff --git a/src/librustdoc/html/render/write_shared.rs b/src/librustdoc/html/render/write_shared.rs
index c1a83ad5820..e4c2556118a 100644
--- a/src/librustdoc/html/render/write_shared.rs
+++ b/src/librustdoc/html/render/write_shared.rs
@@ -39,8 +39,9 @@ static FILES_UNVERSIONED: Lazy> = Lazy::new(|| {
"SourceCodePro-Semibold.ttf.woff" => static_files::source_code_pro::SEMIBOLD,
"SourceCodePro-It.ttf.woff" => static_files::source_code_pro::ITALIC,
"SourceCodePro-LICENSE.txt" => static_files::source_code_pro::LICENSE,
- "noto-sans-kr-v13-korean-regular.woff" => static_files::noto_sans_kr::REGULAR,
- "noto-sans-kr-v13-korean-regular-LICENSE.txt" => static_files::noto_sans_kr::LICENSE,
+ "noto-sans-kr-regular.woff2" => static_files::noto_sans_kr::REGULAR2,
+ "noto-sans-kr-regular.woff" => static_files::noto_sans_kr::REGULAR,
+ "noto-sans-kr-LICENSE.txt" => static_files::noto_sans_kr::LICENSE,
"LICENSE-MIT.txt" => static_files::LICENSE_MIT,
"LICENSE-APACHE.txt" => static_files::LICENSE_APACHE,
"COPYRIGHT.txt" => static_files::COPYRIGHT,
diff --git a/src/librustdoc/html/static/css/rustdoc.css b/src/librustdoc/html/static/css/rustdoc.css
index 962af66368d..11c54876dea 100644
--- a/src/librustdoc/html/static/css/rustdoc.css
+++ b/src/librustdoc/html/static/css/rustdoc.css
@@ -75,12 +75,13 @@
font-display: swap;
}
-/* Avoid using legacy CJK serif fonts in Windows like Batang */
+/* Avoid using legacy CJK serif fonts in Windows like Batang. */
@font-face {
font-family: 'Noto Sans KR';
- src: url("noto-sans-kr-v13-korean-regular.woff") format("woff");
+ src: url("noto-sans-kr-regular.woff2") format("woff2"),
+ url("noto-sans-kr-regular.woff") format("woff");
font-display: swap;
- unicode-range: U+A960-A97F, U+AC00-D7AF, U+D7B0-D7FF;
+ unicode-range: U+AC00-D7AF, U+3130-318F, U+1100-11FF, U+A960-A97F, U+D7B0-D7FF;
}
* {
diff --git a/src/librustdoc/html/static/fonts/noto-sans-kr-v13-korean-regular-LICENSE.txt b/src/librustdoc/html/static/fonts/noto-sans-kr-LICENSE.txt
similarity index 100%
rename from src/librustdoc/html/static/fonts/noto-sans-kr-v13-korean-regular-LICENSE.txt
rename to src/librustdoc/html/static/fonts/noto-sans-kr-LICENSE.txt
diff --git a/src/librustdoc/html/static/fonts/noto-sans-kr-v13-korean-regular.woff b/src/librustdoc/html/static/fonts/noto-sans-kr-regular.woff
similarity index 94%
rename from src/librustdoc/html/static/fonts/noto-sans-kr-v13-korean-regular.woff
rename to src/librustdoc/html/static/fonts/noto-sans-kr-regular.woff
index 01d6b6b5466..65e939c6b9f 100644
Binary files a/src/librustdoc/html/static/fonts/noto-sans-kr-v13-korean-regular.woff and b/src/librustdoc/html/static/fonts/noto-sans-kr-regular.woff differ
diff --git a/src/librustdoc/html/static/fonts/noto-sans-kr-regular.woff2 b/src/librustdoc/html/static/fonts/noto-sans-kr-regular.woff2
new file mode 100644
index 00000000000..8126492e41d
Binary files /dev/null and b/src/librustdoc/html/static/fonts/noto-sans-kr-regular.woff2 differ
diff --git a/src/librustdoc/html/static_files.rs b/src/librustdoc/html/static_files.rs
index ccc25e6cc49..924e3f1d29d 100644
--- a/src/librustdoc/html/static_files.rs
+++ b/src/librustdoc/html/static_files.rs
@@ -157,15 +157,14 @@ crate mod source_code_pro {
}
crate mod noto_sans_kr {
- /// The file `noto-sans-kr-v13-korean-regular.woff`, the Regular variant of the Noto Sans KR
- /// font.
- crate static REGULAR: &[u8] =
- include_bytes!("static/fonts/noto-sans-kr-v13-korean-regular.woff");
+ /// The file `noto-sans-kr.woff`, the Regular variant of the Noto Sans KR font.
+ crate static REGULAR: &[u8] = include_bytes!("static/fonts/noto-sans-kr-regular.woff");
- /// The file `noto-sans-kr-v13-korean-regular-LICENSE.txt`, the license text of the Noto Sans KR
- /// font.
- crate static LICENSE: &[u8] =
- include_bytes!("static/fonts/noto-sans-kr-v13-korean-regular-LICENSE.txt");
+ /// The file `noto-sans-kr.woff2`, the Regular variant of the Noto Sans KR font.
+ crate static REGULAR2: &[u8] = include_bytes!("static/fonts/noto-sans-kr-regular.woff2");
+
+ /// The file `noto-sans-kr-LICENSE.txt`, the license text of the Noto Sans KR font.
+ crate static LICENSE: &[u8] = include_bytes!("static/fonts/noto-sans-kr-LICENSE.txt");
}
/// Files related to the sidebar in rustdoc sources.